@@ -35,7 +35,7 @@
 #' cluster extraction methods from hierarchical representations (such as
 #' [hclust] objects) generally rely on global parameters or cutting values
 #' which are used to partition a cluster hierarchy into a set of disjoint, flat
-#' clusters. This is implemented in R in function [cutree()].
+#' clusters. This is implemented in R in function [stats::cutree()].
 #' Although such methods are widespread, using global parameter
 #' settings are inherently limited in that they cannot capture patterns within
 #' the cluster hierarchy at varying _local_ levels of granularity.
@@ -223,9 +223,8 @@ extractFOSC <-
         ## Checks for proper indexing, symmetry of constraints, etc.
         if (validate_constraints) {
           is_valid <- max(as.integer(names(constraints))) < n
-          is_valid <-
-            is_valid && all(sapply(constraints, function(ilc)
-              all(ilc <= n)))
+          is_valid <- is_valid &&
+            all(vapply(constraints, function(ilc) all(ilc <= n), logical(1L)))
           if (!is_valid) {
             stop("Detected constraint indices not in the interval [1, n]")
           }
@@ -279,47 +278,40 @@ extractFOSC <-
         cl_tree <-
           extractSemiSupervised(cl_tree, constraints_list, alpha, prune_unstable)
       } else {
-        stop(paste(
-          "'extractFOSC' doesn't know how to handle constraints of type",
+        stop(
+          "'extractFOSC' doesn't know how to handle constraints of type ",
           class(constraints)
-        ))
+        )
       }
     }
-    total_stab <-
-      if (is.null(attr(cl_tree, "total_stability")))
-        1
-    else
-      attr(cl_tree, "total_stability")
     cl_track <- attr(cl_tree, "cl_tracker")
     stability_score <-
-      unlist(sapply(cl_track, function(cid)
-        cl_tree[[as.character(cid)]]$stability))
+      vapply(cl_track, function(cid)
+        cl_tree[[as.character(cid)]]$stability, numeric(1L))
     constraint_score <-
-      unlist(sapply(cl_track, function(cid)
-        cl_tree[[as.character(cid)]]$vscore))
+      vapply(cl_track, function(cid)
+        cl_tree[[as.character(cid)]]$vscore %||% 0, numeric(1L))
     total_score <-
-      unlist(sapply(cl_track, function(cid)
-        cl_tree[[as.character(cid)]]$vscore))
+      vapply(cl_track, function(cid)
+        cl_tree[[as.character(cid)]]$score %||% 0, numeric(1L))
     out <- append(
       x,
       list(
-        "cluster" = cl_track,
-        "stability" = stability_score,
-        "constraint" = constraint_score,
-        "total" = total_score
+        cluster = cl_track,
+        stability = stability_score,
+        constraint = constraint_score,
+        total = total_score
       )
     )
     extraction_type <-
-      ifelse(
-        missing(constraints),
-        "(w/ stability-based extraction)",
-        ifelse(
-          alpha == 0,
-          "(w/ constraint-based extraction)",
-          "(w/ mixed-objective extraction)"
-        )
-      )
-    substrs <- unlist(strsplit(x$method, split = " \\(w\\/"))
+      if (missing(constraints)) {
+        "(w/ stability-based extraction)"
+      } else if (alpha == 0) {
+        "(w/ constraint-based extraction)"
+      } else {
+        "(w/ mixed-objective extraction)"
+      }
+    substrs <- strsplit(x$method, split = " \\(w\\/")[[1L]]
     out[["method"]] <-
       if (length(substrs) > 1)
         paste(substrs[[1]], extraction_type)
